@@ -52,15 +52,13 @@ class ContractCall(ContextMixin):
             amount=amount,
         )
 
-    def as_transaction(self) -> OperationGroup:
+    def as_transaction(self, **kwargs) -> OperationGroup:
         """Get operation content.
 
         :rtype: OperationGroup
         """
         return OperationGroup(context=self._spawn_context()).transaction(
-            destination=self.address,
-            amount=self.amount,
-            parameters=self.parameters,
+            destination=self.address, amount=self.amount, parameters=self.parameters, **kwargs
         )
 
     @property  # type: ignore
@@ -85,6 +83,32 @@ class ContractCall(ContextMixin):
         """
         return self.as_transaction().send(gas_reserve=gas_reserve, burn_reserve=burn_reserve, min_confirmations=min_confirmations, ttl=ttl)
 
+    def send_async(
+        self,
+        ttl: int,
+        counter: int,
+        gas_limit: int,
+        storage_limit: int,
+        minimal_nanotez_per_gas_unit: Optional[int] = None,
+    ) -> 'OperationGroup':
+        """
+        Send operation without simulation or pre-validation
+
+        :param ttl: Number of blocks to wait in the mempool before removal (default is 5 for public network, 60 for sandbox)
+        :param counter: Set counter value
+        :param gas_limit: Set gas_limit value
+        :param storage_limit: Set storage_limit value
+        :param minimal_nanotez_per_gas_unit: Override minimal_nanotez_per_gas_unit constant
+        :rtype: OperationGroup
+        """
+        return self.as_transaction().send_async(
+            ttl=ttl,
+            counter=counter,
+            gas_limit=gas_limit,
+            storage_limit=storage_limit,
+            minimal_nanotez_per_gas_unit=minimal_nanotez_per_gas_unit,
+        )
+
     @deprecated(deprecated_in='3.2.2', removed_in='4.0.0', details='use `send()` instead')
     def inject(self, _async=True, preapply=True, check_result=True, num_blocks_wait=5) -> OperationGroup:
         """Send operation to blockchain."""
